import 'package:flutter/material.dart';

enum AnimationTypes { none, slideLeft, slideRight, slideUp, opacity }

enum DialogAnimationTypes { none, feedIn, open, opacity }

class AnimationHelper {
  AnimationHelper._();

  static Widget _animationSlideLeft(
      BuildContext context,
      Animation<double> animation,
      Animation<double> secondaryAnimation,
      Widget child) {
    return SlideTransition(
      position: Tween<Offset>(
        begin: const Offset(1.0, 0.0),
        end: Offset.zero,
      ).animate(animation),
      child: child,
    );
  }

  static Widget _animationSlideRight(
      BuildContext context,
      Animation<double> animation,
      Animation<double> secondaryAnimation,
      Widget child) {
    return SlideTransition(
      position: Tween<Offset>(begin: const Offset(-1.0, 0.0), end: Offset.zero)
          .animate(animation),
      child: child,
    );
  }

  static Widget _animationSlideUp(
      BuildContext context,
      Animation<double> animation,
      Animation<double> secondaryAnimation,
      Widget child) {
    return SlideTransition(
      position: Tween<Offset>(begin: const Offset(0.0, 1.0), end: Offset.zero)
          .animate(animation),
      child: child,
    );
  }

  static Widget _animationOpacity(
      BuildContext context,
      Animation<double> animation,
      Animation<double> secondaryAnimation,
      Widget child) {
    return Opacity(
      opacity: animation.value,
      child: child,
    );
  }

  static Widget Function(
          BuildContext, Animation<double>, Animation<double>, Widget)
      getAnimation(AnimationTypes type) {
    switch (type) {
      // case AnimationTypes.none:
      //   return null;
      case AnimationTypes.opacity:
        return _animationOpacity;
      case AnimationTypes.slideLeft:
        return _animationSlideLeft;
      case AnimationTypes.slideRight:
        return _animationSlideRight;
      case AnimationTypes.slideUp:
        return _animationSlideUp;
      default:
        return _animationOpacity;
    }
  }
}
